==> nextcloud-21.0.4.tgz: nextcloud/apps/updatenotification/l10n/cs.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Je k dispozici {version}. Přečtěte si informace o tom, jak aktualizovat.",
    "Channel updated" : "Kanál aktualizován",
    "Web updater is disabled" : "Nástroj pro aktualizaci přes webové rozhraní je vypnutý",
    "Update notifications" : "Upozorňování na aktualizace",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizační server nebyl %d dní dosažitelný pro kontrolu aktualizací.",
    "Please check the Nextcloud and server log files for errors." : "Podívejte se po chybách v záznamu událostí Nextcloud a serveru.",
    "Update to %1$s is available." : "Je k dispozici aktualizace na %1$s.",
    "Update for %1$s to version %2$s is available." : "Je k dispozici aktualizace pro %1$s na verzi %2$s.",
    "Update for {app} to version %s is available." : "Pro {app} je dostupná aktualizace na verzi %s.",
    "Update notification" : "Upozornění na aktualizaci",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Zobrazí upozornění na aktualizace pro Nextcloud a poskytuje sjednocené přihlašování pro nástroj pro provedení aktualizace.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Verze, kterou provozujete, už není udržovaná. Aktualizujte co nejdříve na podporovanou verzi.",
    "Apps missing compatible version" : "Aplikace, které neexistují v kompatibilní verzi",
    "View in store" : "Zobrazit v katalogu aplikací",
    "Apps with compatible version" : "Aplikace, které existují v kompatibilní verzi",
    "Open updater" : "Otevřít nástroj pro aktualizaci",
    "Download now" : "Stáhnout nyní",
    "Please use the command line updater to update." : "Aktualizaci proveďte nástrojem z příkazového řádku.",
    "What's new?" : "Co je nového?",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizací ještě neskončila. Načtěte stránku znovu.",
    "Your version is up to date." : "Používáte nejnovější verzi.",
    "A non-default update server is in use to be checked for updates:" : "Pro kontrolu aktualizací se používá jiný než výchozí server:",
    "Update channel:" : "Kanál aktualizací:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vždy je možné přejít na novější verzi. Poté už se ale nelze vrátit zpět ke starší verzi ze stabilnějšímu kanálu.",
    "Notify members of the following groups about available updates:" : "Upozorňovat členy následujících skupin na dostupnost aktualizací:",
    "Only notifications for app updates are available." : "K dispozici jsou upozornění pouze na aktualizace aplikací.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Pro zvolený kanál aktualizací se už vyhrazená upozorňování pro server nepoužívají.",
    "The selected update channel does not support updates of the server." : "Vybraný kanál aktualizací nepodporuje aktualizace serveru.",
    "A new version is available: <strong>{newVersionString}</strong>" : "K dispozici je nová verze: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Můžete si všimnout, že po vydání nové verze se aktualizace objeví až po vydání první opravné aktualizace. Nové verze totiž distribuujeme mezi uživatele postupně a občas, pokud jsou nalezeny chyby, danou verzi i přeskočíme. Zjištěte více o aktualizacích a kanálech aktualizací kliknutím na {link}",
    "Checked on {lastCheckedDate}" : "Zkontrolováno {lastCheckedDate}",
    "Checking apps for compatible versions" : "Kontrola kompatibilních verzí aplikací",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Ověřte, že v souboru s nastaveními config.php není volba <samp>appstoreenabled</samp> nastavena na hodnotu false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Nedaří se spojit s katalogem aplikací nebo tento nevrátil vůbec žádné aktualizace. Vyhledejte aktualizace ručně nebo ověřte, zda má váš server přístup k Internetu a může se spojit s katalogem.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Všechny</strong> aplikace mají k dispozici kompatibilní verzi s verzí tohoto Nextcloud serveru",
    "View changelog" : "Zobrazit souhrn změn",
    "Enterprise" : "Podnikové",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pro podnikové nasazení. Poskytuje vždy nejnovější opravy, ale nebude hned aktualizováno na další hlavní vydání. K tomu dochází až když Nextcloud GmbH dokončí další zodolnění a testování pro rozsáhlá a kritická nasazení. Tento kanál je k dispozici pouze zákazníkům a poskytuje balíček Nextcloud Enterprise.",
    "Stable" : "Stabilní",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Nejnovější stabilní verze. Je vhodná pro běžné používání a vždy ji lze aktualizovat na nejnovější hlavní verzi",
    "Beta" : "Vývojové",
    "A pre-release version only for testing new features, not for production environments." : "Předprodukční verze, pouze pro zkoušení nových funkcí, není určeno pro praktické nasazení.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> aplikace nemá kompatibilní verzi pro verzi tohoto Nextcloud serveru","<strong>%n</strong> aplikace nemají kompatibilní verzi pro verzi tohoto Nextcloud serveru","<strong>%n</strong> aplikací nemá kompatibilní verzi pro verzi tohoto Nextcloudu","1%n1 aplikace nemají kompatibilní verzi pro verzi tohoto Nextcloud serveru"],
    "Apps missing updates" : "Aplikace s chybějícími aktualizacemi",
    "Apps with available updates" : "Aplikace s dostupnými aktualizacemi",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Všimněte si, že po vydání nové verze může chvíli trvat, než se zde objeví. Nové verze totiž distribuujeme mezi uživatele postupně a pokud jsou nalezeny problémy, někdy danou verzi přeskočíme.",
    "Only notification for app updates are available." : "K dispozici jsou upozornění pouze na aktualizace aplikací.",
    "Checking apps for compatible updates" : "Zjišťuje se dostupnost kompatibilních aktualizací aplikací",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Nedaří se spojit s katalogem aplikací nebo tento nevrátil vůbec žádné aktualizace. Vyhledejte aktualizace ručně nebo ověřte, zda má váš server přístup k Internetu a může se spojit s katalogem.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Všehny</strong> aplikace mají k dispozici aktualizaci pro tuto verzi",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikace nemá k dispozici aktualizaci na tuto verzi","<strong>%n</strong>  aplikace nemají k dispozici aktualizaci na tuto verzi","<strong>%n</strong> aplikací nemá k dispozici aktualizaci na tuto verzi","<strong>%n</strong> aplikace nemají k dispozici aktualizaci na tuto verzi"]
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/updatenotification/l10n/cs.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Je k dispozici {version}. Přečtěte si informace o tom, jak aktualizovat.",
    "Channel updated" : "Kanál aktualizován",
    "Web updater is disabled" : "Nástroj pro aktualizaci přes webové rozhraní je vypnutý",
    "Update notifications" : "Upozorňování na aktualizace",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizační server nebyl %d dní dosažitelný pro kontrolu aktualizací.",
    "Please check the Nextcloud and server log files for errors." : "Podívejte se po chybách v záznamu událostí Nextcloud a serveru.",
    "Update to %1$s is available." : "Je k dispozici aktualizace na %1$s.",
    "Update for %1$s to version %2$s is available." : "Je k dispozici aktualizace pro %1$s na verzi %2$s.",
    "Update for {app} to version %s is available." : "Pro {app} je dostupná aktualizace na verzi %s.",
    "Update notification" : "Upozornění na aktualizaci",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Zobrazí upozornění na aktualizace pro Nextcloud a poskytuje sjednocené přihlašování pro nástroj pro provedení aktualizace.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Verze, kterou provozujete, už není udržovaná. Aktualizujte co nejdříve na podporovanou verzi.",
    "Apps missing compatible version" : "Aplikace, které neexistují v kompatibilní verzi",
    "View in store" : "Zobrazit v katalogu aplikací",
    "Apps with compatible version" : "Aplikace, které existují v kompatibilní verzi",
    "Open updater" : "Otevřít nástroj pro aktualizaci",
    "Download now" : "Stáhnout nyní",
    "Please use the command line updater to update." : "Aktualizaci proveďte nástrojem z příkazového řádku.",
    "What's new?" : "Co je nového?",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizací ještě neskončila. Načtěte stránku znovu.",
    "Your version is up to date." : "Používáte nejnovější verzi.",
    "A non-default update server is in use to be checked for updates:" : "Pro kontrolu aktualizací se používá jiný než výchozí server:",
    "Update channel:" : "Kanál aktualizací:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vždy je možné přejít na novější verzi. Poté už se ale nelze vrátit zpět ke starší verzi ze stabilního kanálu.",
    "Notify members of the following groups about available updates:" : "Upozorňovat členy následujících skupin na dostupnost aktualizací:",
    "Only notifications for app updates are available." : "K dispozici jsou upozornění pouze na aktualizace aplikací.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Pro zvolený kanál aktualizací se už vyhrazená upozorňování pro server nepoužívají.",
    "The selected update channel does not support updates of the server." : "Vybraný kanál aktualizací nepodporuje aktualizace serveru.",
    "A new version is available: <strong>{newVersionString}</strong>" : "K dispozici je nová verze: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Můžete si všimnout, že po vydání nové verze se aktualizace objeví až po vydání první opravné aktualizace. Nové verze totiž distribuujeme mezi uživatele postupně a občas, pokud jsou nalezeny chyby, danou verzi i přeskočíme. Zjištěte více o aktualizacích a kanálech aktualizací kliknutím na {link}",
    "Checked on {lastCheckedDate}" : "Zkontrolováno {lastCheckedDate}",
    "Checking apps for compatible versions" : "Kontrola kompatibilních verzí aplikací",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Ověřte, že v souboru s nastaveními config.php není volba <samp>appstoreenabled</samp> nastavena na hodnotu false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Nedaří se spojit s katalogem aplikací nebo tento nevrátil vůbec žádné aktualizace. Vyhledejte aktualizace ručně nebo ověřte, zda má váš server přístup k Internetu a může se spojit s katalogem.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Všechny</strong> aplikace mají k dispozici kompatibilní verzi s verzí tohoto Nextcloud serveru.",
    "View changelog" : "Zobrazit souhrn změn",
    "Enterprise" : "Podnikové",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pro podnikové nasazení. Poskytuje vždy nejnovější opravy, ale nebude hned aktualizováno na další hlavní vydání. K tomu dochází až když Nextcloud GmbH dokončí další zodolnění a testování pro rozsáhlá a kritická nasazení. Tento kanál je k dispozici pouze zákazníkům a poskytuje balíček Nextcloud Enterprise.",
    "Stable" : "Stabilní",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Nejnovější stabilní verze. Je vhodná pro běžné používání a vždy ji lze aktualizovat na nejnovější hlavní verzi",
    "Beta" : "Vývojové",
    "A pre-release version only for testing new features, not for production environments." : "Předprodukční verze, pouze pro zkoušení nových funkcí, není určeno pro praktické nasazení.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["1%n1 aplikace nemá kompatibilní verzi pro verzi tohoto Nextcloud serveru.","1%n1 aplikace nemají kompatibilní verzi pro verzi tohoto Nextcloud serveru.","1%n1 aplikací nemá kompatibilní verzi pro verzi tohoto Nextcloud serveru.","1%n1 aplikace nemají kompatibilní verzi pro verzi tohoto Nextcloud serveru."],
    "Apps missing updates" : "Aplikace s chybějícími aktualizacemi",
    "Apps with available updates" : "Aplikace s dostupnými aktualizacemi",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Všimněte si, že po vydání nové verze může chvíli trvat, než se zde objeví. Nové verze totiž distribuujeme mezi uživatele postupně a pokud jsou nalezeny problémy, někdy danou verzi přeskočíme.",
    "Only notification for app updates are available." : "K dispozici jsou upozornění pouze na aktualizace aplikací.",
    "Checking apps for compatible updates" : "Zjišťuje se dostupnost kompatibilních aktualizací aplikací",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Nedaří se spojit s katalogem aplikací nebo tento nevrátil vůbec žádné aktualizace. Vyhledejte aktualizace ručně nebo ověřte, zda má váš server přístup k Internetu a může se spojit s katalogem.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Všehny</strong> aplikace mají k dispozici aktualizaci pro tuto verzi",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikace nemá k dispozici aktualizaci na tuto verzi","<strong>%n</strong>  aplikace nemají k dispozici aktualizaci na tuto verzi","<strong>%n</strong> aplikací nemá k dispozici aktualizaci na tuto verzi","<strong>%n</strong> aplikace nemají k dispozici aktualizaci na tuto verzi"],
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Všechny</strong> aplikace mají k dispozici kompatibilní verzi s verzí tohoto Nextcloud serveru",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> aplikace nemá kompatibilní verzi pro verzi tohoto Nextcloud serveru","<strong>%n</strong> aplikace nemají kompatibilní verzi pro verzi tohoto Nextcloud serveru","<strong>%n</strong> aplikací nemá kompatibilní verzi pro verzi tohoto Nextcloudu","1%n1 aplikace nemají kompatibilní verzi pro verzi tohoto Nextcloud serveru"]
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
